@@ -100,18 +100,21 @@ class DisplayCommandBase(command.Command):
             columns_to_include = [c for c in column_names
                                   if c in parsed_args.columns]
             if not columns_to_include:
-                raise ValueError('No recognized column names in %s' %
-                                 str(parsed_args.columns))
+                raise ValueError('No recognized column names in %s. '
+                                 'Recognized columns are %s.' %
+                                 (str(parsed_args.columns), str(column_names)))
+
             # Set up argument to compress()
             selector = [(c in columns_to_include)
                         for c in column_names]
         return columns_to_include, selector
 
     def run(self, parsed_args):
-        self._run_before_hooks(parsed_args)
+        parsed_args = self._run_before_hooks(parsed_args)
         self.formatter = self._formatter_plugins[parsed_args.formatter].obj
         column_names, data = self.take_action(parsed_args)
-        self._run_after_hooks(parsed_args, (column_names, data))
+        column_names, data = self._run_after_hooks(parsed_args,
+                                                   (column_names, data))
         self.produce_output(parsed_args, column_names, data)
         return 0
 
